netapp_ontap.models.layout_requirement API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.layout_requirement`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LayoutRequirementSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LayoutRequirement object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aggregate_min_disks: Size GET`

    Minimum number of disks to create an aggregate.

    Example: 6

  `default: bool GET`

    Indicates if this RAID type is the default.

  `raid_group: LayoutRequirementRaidGroup GET`

    The raid_group field of the layout_requirement.

  `raid_type: str GET`

    RAID type.

    Valid choices:

    - raid_dp
    - raid_tec
    - raid4
    - raid0